@@ -29,16 +29,18 @@ sub register {
             debug       => 1,        
         );
 
-        $r->get( '/source/' => sub { shift->redirect_to('/source/index.html') });
-
         # relative path
         my $rel_static = Mojolicious::Static->new();
         $rel_static->root($qx_app_src);
         my $rel_static_cb = sub {
-                my $self = shift;
-                return $rel_static->dispatch($self);
+             my $self = shift;
+             if (not $self->stash->{file}){
+                 $self->req->url->path($self->req->url->path.'index.html');
+             }
+             return $rel_static->dispatch($self);
         };
-        $r->route('/source/(*b)')->to( cb => $rel_static_cb );
+        $r->get('/source/(*file)' => $rel_static_cb );
+        $r->get('/source/' => $rel_static_cb );
 
         my $abs_static = Mojolicious::Static->new();
         my %prefixCache;
@@ -60,8 +62,8 @@ sub register {
             return $abs_static->dispatch($self);
         };
 
-        $r->route('/(*prefix)/framework/source/(*b)')->to( cb => $abs_static_cb );
-        $r->route('/(*prefix)/downloads/(*b)/source/(*c)')->to( cb => $abs_static_cb );
+        $r->get('/(*prefix)/framework/source/(*b)' => $abs_static_cb );
+        $r->get('/(*prefix)/downloads/(*b)/source/(*c)' => $abs_static_cb );
 
     };
     $r->route($path)->to(
@@ -71,9 +73,7 @@ sub register {
         # our own properties
         services    => $services
     );
-
-    $r->get( '/' => sub { shift->redirect_to('/index.html') });
-
+    $r->get( '/' => sub { shift->render_static('index.html') });
 }
 
 1;
